netapp_ontap.models.application_statistics API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.application_statistics`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ApplicationStatisticsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ApplicationStatistics object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `components: List[ApplicationStatisticsComponents] GET`

    The components field of the application_statistics.

  `iops: ApplicationStatisticsIops GET POST PATCH`

    The iops field of the application_statistics.

  `latency: ApplicationStatisticsLatency GET POST PATCH`

    The latency field of the application_statistics.

  `shared_storage_pool: bool GET`

    An application is considered to use a shared storage pool if storage elements for multiple components reside on the same aggregate.

  `snapshot: ApplicationStatisticsComponentsSnapshot GET POST PATCH`

    The snapshot field of the application_statistics.

  `space: ApplicationStatisticsSpace GET POST PATCH`

    The space field of the application_statistics.

  `statistics_incomplete: bool GET`

    If not all storage elements of the application are currently available, the returned statistics might only include data from those elements that were available.